@@ -71,9 +71,9 @@ def perform_actions(action_list, printer):
 # THE ACTIONS
 
 def display_alert(args,printer):
-    alert_title = args[u'alert_title']
-    alert_message = args[u'alert_message']
-    urgency = args[u'urgency']
+    alert_title = args['alert_title']
+    alert_message = args['alert_message']
+    urgency = args['urgency']
     cmd = construct_notification_command(alert_title, alert_message, urgency)
     #    pdb.set_trace()
     if debug: 
